@@ -35,7 +35,8 @@ class Kart:
         default = {
             "name": "Example",
             "base_url": "https://example.org",
-            "pagination": {"per_page": 5, "skip": 1},
+            "pagination": {"per_page": 5, "skip": 0},
+            "timezone": "UTC",
         }
         merge_dicts(self.config, default)
 
@@ -99,8 +100,11 @@ class Kart:
         if url in urls:
             page = site_map[urls[url]]
         else:
-            pattern = next((x for x in regexes if fnmatch.fnmatch(url, x)))
-            page = site_map[regexes[pattern]]
+            try:
+                pattern = next((x for x in regexes if fnmatch.fnmatch(url, x)))
+                page = site_map[regexes[pattern]]
+            except StopIteration:
+                page = None
         if page:
             self.renderer_dict[page["renderer"]].serve(handler, page, site_map, site)
 
@@ -148,5 +152,5 @@ class Kart:
         if args.command == "build":
             self.build()
         if args.command == "serve":
-            self.config["base_url"] = ""
+            self.config["base_url"] = f"http://localhost:{args.port}"
             self.serve(args.port)
